import {Component, Output, EventEmitter, ChangeDetectionStrategy, Input, TemplateRef, ViewChild} from '@angular/core';
import {Http, ResponseContentType} from '@angular/http';
import {CookieService} from 'ngx-cookie-service';
import {Headers} from '@angular/http';
import * as FileSaver from 'file-saver';

@Component({
    selector: 'datatable-footer',
    template: `
        <div
                class="datatable-footer-inner"
                [ngClass]="{'selected-count': selectedMessage}"
                [style.height.px]="footerHeight">
            <ng-template
                    *ngIf="footerTemplate"
                    [ngTemplateOutlet]="footerTemplate.template"
                    [ngTemplateOutletContext]="{ 
          rowCount: rowCount, 
          pageSize: pageSize, 
          selectedCount: selectedCount,
          curPage: curPage,
          offset: offset
        }">
            </ng-template>
            <div class="page-count" *ngIf="!footerTemplate">
        <span *ngIf="selectedMessage">
          {{selectedCount.toLocaleString()}} {{selectedMessage}} /
        </span>
                {{rowCount.toLocaleString()}} {{totalMessage}}
            </div>
            <datatable-pager *ngIf="!footerTemplate"
                             [pagerLeftArrowIcon]="pagerLeftArrowIcon"
                             [pagerRightArrowIcon]="pagerRightArrowIcon"
                             [pagerPreviousIcon]="pagerPreviousIcon"
                             [pagerNextIcon]="pagerNextIcon"
                             [page]="curPage"
                             [size]="pageSize"
                             [count]="rowCount"
                             [hidden]="!isVisible"
                             (change)="page.emit($event)">
            </datatable-pager>
            <ul style="display:flex ;   float: left;">
                <li style="display:   inline-block ;padding: 10px;;">
                    <select #selected (click)="onClick(selected.value)">
                        <option value="5">5</option>
                        <option value="10">10</option>
                        <option value="15">15</option>
                        <option value="20">20</option>
                    </select>
                </li>
                <li style="display:  inline-block;padding: 10px;">
                    <input type="image" src="http://uupload.ir/files/b1dp_pdf.png" height="18px" (click)="exportPdf()"
                           style="height:18px ; width:18px"/>
                </li>
                <li style="display: inline-block;     padding: 10px;">
                    <input type="image" src="http://uupload.ir/files/v8vt_excel.png" (click)="exportExcel()"
                           style="height:18px ; width:18px"/>
                </li>
            </ul>
        </div>
    `,
    host: {
        class: 'datatable-footer'
    },
    changeDetection: ChangeDetectionStrategy.OnPush
})
export class DataTableFooterComponent {
    columnsArray: any[];
    @Input() rows: any;
    @Input() appUrl: any;
    @Input() resource: any;
    @Input() sortDir: any;
    @Input() sortProp: any;
    @Input() includes: any;
    @Input() filters: any;
    @Input() columns: any;
    @Input() footerHeight: number;
    @Input() rowCount: number;
    @Input() pageSize: number;
    @Input() offset: number;
    @Input() pagerLeftArrowIcon: string;
    @Input() pagerRightArrowIcon: string;
    @Input() pagerPreviousIcon: string;
    @Input() pagerNextIcon: string;
    @Input() totalMessage: string;
    @Input() footerTemplate: TemplateRef<any>;
    @Input() selectedCount: number = 0;
    @Input() selectedMessage: string | boolean;
    @Output() page: EventEmitter<any> = new EventEmitter();
    // for test out put  for emit value of selected
    @Output() selectedValue = new EventEmitter();

    get isVisible(): boolean {
        return (this.rowCount / this.pageSize) > 1;
    }

    get curPage(): number {
        return this.offset + 1;
    }

    onClick(value: any) {
        this.selectedValue.emit(value);
    }

    @ViewChild('selected') selected: any;

    constructor(private http: Http,
                private cookieService: CookieService,) {
        this.columnsArray = [];
    }

    repairRows(arr: any[]): string {
        const rv: any[] = [];
        for (let i = 0; i < arr.length; ++i)
            if (arr[i] !== undefined) {
                rv.push(Object.assign({}, arr[i]));
                return JSON.stringify(rv);
            }
    }

    repaircolumns(arr: any[]): string {
        this.columnsArray = [];
        console.log('attay', arr);
        for (const key in arr) {
            console.log(arr[key]);
            const obj = {
                // key: this.columns[key]['prop'],
                // value: this.columns[key]['name'],
                // is_relationship : this.columns[key]['isRelationship']
                key: arr[key]['prop'],
                value: arr[key]['name'],
                is_relationship: arr[key]['isRelationship']
            };
            if (!obj.is_relationship) {
                obj.is_relationship = false;
            }
            this.columnsArray.push(obj);
        }
        return JSON.stringify(this.columnsArray);
    }

    exportExcel(): any {
        const token = this.cookieService.get('token');
        const headers = new Headers();
        headers.append('Content-Type', 'application/x-www-form-urlencoded');
        headers.append('Authorization', 'Bearer ' + token);
        return this.http.post(this.appUrl + 'excel', 'type=' + 'excel' +
            '&filters=' + JSON.stringify(this.filters) + '&columns=' + this.repaircolumns(this.columns) + '&sortDir=' + this.sortDir +
            '&sortProp=' + this.sortProp + '&resource=' + this.resource,
            {headers: headers, responseType: ResponseContentType.Blob}
        ).subscribe(x => {
                var url = window.URL.createObjectURL(new Blob([x['_body']]));
                var a = document.createElement('a');
                document.body.appendChild(a);
                a.setAttribute('style', 'display: none');
                a.href = url;
                a.download = 'table.xlsx';
                a.click();
                window.URL.revokeObjectURL(url);
                a.remove(); // remove the element
            }
        );
    }

    exportPdf(): any {
        const token = this.cookieService.get('token');
        const headers = new Headers();
        headers.append('Content-Type', 'application/force-download');
        headers.append('Authorization', 'Bearer ' + token);
        return this.http.post(this.appUrl + 'pdf', 'type=' + 'pdf' +
            '&filters=' + JSON.stringify(this.filters) + '&columns=' + this.repaircolumns(this.columns) +
            '&sortDir=' + this.sortDir +
            '&sortProp=' + this.sortProp + '&resource=' + this.resource
            , {headers: headers, responseType: ResponseContentType.Blob}
        ).subscribe(x => {
            console.log('response x', x);
            //     787878
            var newBlob = new Blob([x['_body']], {type: 'application/pdf'});

            if (window.navigator && window.navigator.msSaveOrOpenBlob) {
                window.navigator.msSaveOrOpenBlob(newBlob);
                return;
            }
            const data = window.URL.createObjectURL(newBlob);
            var link = document.createElement('a');
            link.href = data;
            link.download = 'table.pdf';
            link.dispatchEvent(new MouseEvent('click', {bubbles: true, cancelable: true, view: window}));
            setTimeout(function() {
                window.URL.revokeObjectURL(data);
            }, 100);
        });
    }
}
