import {NgModule} from '@angular/core';
import {RouterModule} from '@angular/router';
import {CommonModule} from '@angular/common';
import {
  MatIconModule,
  MatCardModule,
  MatInputModule,
  MatCheckboxModule,
  MatButtonModule,
  MatSelectModule,
  DateAdapter, MAT_DATE_LOCALE, MAT_DATE_FORMATS, MatDatepickerModule, MatAutocompleteModule, MatProgressBarModule
} from '@angular/material';
import {FormsModule, ReactiveFormsModule} from '@angular/forms';
import {FlexLayoutModule} from '@angular/flex-layout';
import {LoadingModule} from 'ngx-loading';
import {AuthRoutes} from './auth.routing';
import {NotFoundComponent} from './not-found/not-found.component';
import {PasswordSigninComponent} from './passwordSignin/passwordSignin.component';
import {SmstokenSigninComponent} from './smstokenSignin/smstokenSignin.component';
import {MatDialogModule} from '@angular/material/dialog';
import {JalaliMomentDateAdapter} from '../../classes/jalali/jalali-moment-dateAdapter';
import {JALALI_MOMENT_FORMATS} from '../../classes/jalali/jalali-moment-formats';
@NgModule({
  imports: [
    MatDatepickerModule,
    LoadingModule.forRoot({
      backdropBackgroundColour: 'rgba(0,0,0,0.1)',
      backdropBorderRadius: '4px',
      primaryColour: '#0000ff',
      secondaryColour: '#0000ff',
      tertiaryColour: '#0000ff'
    }),
    LoadingModule,
    MatSelectModule,
    CommonModule,
    RouterModule.forChild(AuthRoutes),
    MatIconModule,
    MatCardModule,
    MatInputModule,
    MatCheckboxModule,
    MatButtonModule,
    FlexLayoutModule,
    FormsModule,
    ReactiveFormsModule,
    MatDialogModule,
    MatAutocompleteModule,
    MatProgressBarModule,
  ],
  declarations: [
    NotFoundComponent,
    PasswordSigninComponent,
    SmstokenSigninComponent,

  ],
  providers: [
    { provide: DateAdapter, useClass: JalaliMomentDateAdapter, deps: [MAT_DATE_LOCALE] },
    { provide: MAT_DATE_FORMATS, useValue: JALALI_MOMENT_FORMATS }],
})

export class AuthModule {
}
